#include "stdio.h"
#include "highgui.h"
#include "ASICamera.h"
#include <sys/time.h>
#include <time.h>

#include <unistd.h>
#include "UtilTimer.h"

#define  MAX_CONTROL 7
unsigned int copyCtrlFlag = 0;

void timeoutHandler(void * /* param */)
{
  if (!copyCtrlFlag) {
    // The previous copy operation is done, schedule the next one.
    copyCtrlFlag = 1;
    return;
  }
  else if (copyCtrlFlag == 3) {
    // the prevoius copy operation is timeout, something wrong
    // with the image read out. Quit the current process.
    // Crontab job would restart the process again
    UtilTimer_Term();
    exit(-1);
  }

  copyCtrlFlag += 1;
}

void copyFile(char * src, char * dst)
{
  char buf[1024*1024];
  size_t len;
  FILE * fpSrc = NULL;
  FILE * fpDst = NULL;

  fpSrc = fopen(src, "r");
  if (fpSrc == NULL) {
    printf("Error! Fail to open file %s for read\n", src);
    return;
  }
  fpDst = fopen(dst, "w");
  if (fpDst == NULL) {
    printf("Error! Fail to open file %s for wrte\n", dst);
    return;
  }

  len = fread(buf, 1, 4096, fpSrc);
  while (len != 0) {
    fwrite(buf, len, 1, fpDst);
    len = fread(buf, 1, 4096, fpSrc);
  }

  fclose(fpSrc);
  fclose(fpDst);
}

void cvText(IplImage* img, const char* text, int x, int y)
{
  CvFont font;

  double hscale = 0.6;
  double vscale = 0.6;
  int linewidth = 1;
  cvInitFont(&font,CV_FONT_HERSHEY_SIMPLEX | CV_FONT_ITALIC,hscale,vscale,0,linewidth);

  CvScalar textColor =cvScalar(255,255,255);
  CvPoint textPos =cvPoint(x, y);

  cvPutText(img, text, textPos, &font,textColor);
}

int  main()
{
  struct TimerInfo timerNode;
  void * timerHandler;
  int noise[4000];
  int noiseArraySize = 0;
  int width;
  char* bayer[] = {"RG","BG","GR","GB"};
  char* controls[MAX_CONTROL] = {"Exposure", "Gain", "Gamma", "WB_R", "WB_B", "Brightness", "USB Traffic"};

  int height;
  int i;
  char c;
  bool bresult;

  int CamNum=0;
  FILE * tempfile;
  char tempbuf[256]={0};
  
  ///long exposure, exp_min, exp_max, exp_step, exp_flag, exp_default;
  //long gain, gain_min, gain_max,gain_step, gain_flag, gain_default;

  IplImage *pRgb;

  UtilTimer_Init();

  int numDevices = getNumberOfConnectedCameras();
  if(numDevices <= 0)
  {
    printf("no camera connected.\r\nexit\n");
    return -1;
  }
  else
    printf("attached cameras:\n");

  for(i = 0; i < numDevices; i++)
    printf("%d %s\n",i, getCameraModel(i));

  //printf("\nselect one to privew\n");
  //scanf("%d", &CamNum);
        CamNum = 0;


  bresult = openCamera(CamNum);
  if(!bresult)
  {
    printf("OpenCamera error. Please make sure the program is running with root.\r\nexit\n");
    return -1;
  }

  printf("%s information\n",getCameraModel(CamNum));
  printf("resolution:%dX%d\n", getMaxWidth(),getMaxHeight());
  if(isColorCam())
    printf("Color Camera: bayer pattern:%s\n",bayer[getColorBayer()]);
  else
    printf("Mono camera\n");
  
  for( i = 0; i < MAX_CONTROL; i++)
  {
      if(isAvailable((Control_TYPE)i))
        printf("%s support:Yes\n", controls[i]);
      else
        printf("%s support:No\n", controls[i]);
  }

  width = getMaxWidth();
  height = getMaxHeight();

  initCamera(); //this must be called before camera operation. and it only need init once
  printf("sensor temperature:%02f\n", getSensorTemp());
  setImageFormat(width, height, 1, IMG_RGB24);

  pRgb=cvCreateImage(cvSize(getWidth(),getHeight()), IPL_DEPTH_8U, 3);


  setValue(CONTROL_EXPOSURE, 20*1000, true); //auto exposure 20ms
  setValue(CONTROL_BANDWIDTHOVERLOAD, getMin(CONTROL_BANDWIDTHOVERLOAD), false); //lowest transfer speed
  setValue(CONTROL_GAIN, 30, true);
  setValue(CONTROL_WB_B, 90, false);
  setValue(CONTROL_WB_R, 48, false);
  setAutoPara(50,10,130); //max auto gain and exposure and target brightness
  SetMisc(true,true);// flip x flip y

  EnableDarkSubtract("dark.bmp"); //dark subtract will be disabled when exposure set auto and exposure below 500ms

  startCapture(); //start privew

  // 30 seconds timeout. If copyCtrlFlag is not set twice, the timeout handler
  // would kill the current process.
  timerNode.expires = 30000;
  timerNode.type = TIMER_LOOP;
  timerNode.data = NULL;
  timerNode.callback = timeoutHandler;
  timerHandler = UtilTimer_AddTimer(&timerNode);
  UtilTimer_StartTimer(timerHandler);

	
	

  while(1)
  {
    int ret;
	int exp;
	int temp;
    ret = getImageData((unsigned char*)pRgb->imageData, pRgb->imageSize, -1);

    time_t local_tm = time(NULL);
    tm *ltime=localtime(&local_tm);
    char msg[256];
    int len;

    if (copyCtrlFlag) {
      if (ret) {
        memset(msg, 0x00, sizeof(msg));
        cvText(pRgb, "All sky camera - SuZhou, JiangSu:", 40, 20);
        sprintf(msg, "%s", ctime(&local_tm));
        len = strlen(msg);
        msg[len -1] = 0x00;

        cvText(pRgb, msg, 40,42);
		exp = getValue(CONTROL_EXPOSURE,&bresult );
		temp=getSensorTemp();
		sprintf(tempbuf, 
		"{\n\"timestamp\":\"%4d-%02d-%02dT%02d:%02d:%02d\",\n\"value\":%2.1f\n}", 
			1900+ltime->tm_year,1+ltime->tm_mon,ltime->tm_mday,ltime->tm_hour,ltime->tm_min,ltime->tm_sec, getSensorTemp());
		tempfile = fopen("/run/sensortemp", "wb" );
		fwrite( tempbuf, sizeof(char), strlen(tempbuf),tempfile);
		fclose(tempfile);
		if(exp < 1000)
		sprintf(msg, "sensor temp:%d exp:%dus", temp,exp);
		else if(exp >=1000 && exp <1000*1000)
		sprintf(msg, "sensor temp:%d exp:%dms", temp,exp/1000);
		else
		sprintf(msg, "sensor temp:%d exp:%ds", temp,exp/1000/1000);

        len = strlen(msg);
        msg[len] = 0x00;

        cvText(pRgb, msg, 40,64);
        ret = cvSaveImage("/run/allskycamera.bak.jpg", pRgb);
        copyFile("/run/allskycamera.bak.jpg", "/run/allskycamera.jpg");

        // Copy operation is done. Unarm the flag
        copyCtrlFlag = 0;
      }
    }
  }
END:
  UtilTimer_RemoveTimer(timerHandler);
  stopCapture();
  UtilTimer_Term();
  printf("over\n");
  return 1;
}
